// src/parser/index.ts
import { parse } from "@vue/compiler-sfc";
import MagicString from "magic-string";
import { createUnimport } from "unimport";
var Parser = class {
  constructor(code) {
    this.code = code;
  }
  unimport;
  descriptor;
  autoAddImport;
  isImport;
  parseCode(code) {
    const { descriptor } = parse(code);
    this.descriptor = descriptor;
  }
  async createUnImport(declaration) {
    const unimport = createUnimport({
      imports: [{ name: "default", as: "$dialog", from: declaration + "/index" }]
    });
    this.unimport = unimport;
  }
  async isUnImport() {
    const re = await this.unimport.injectImports(this.code);
    this.isImport = re.imports.length > 0;
    this.autoAddImport = re.code;
  }
  importMoundle(code) {
    const s = new MagicString(code);
    const { source } = this.descriptor;
    s.replace(source, "");
    return s.toString();
  }
  transformer(code, importCode) {
    const s = new MagicString(code);
    const { scriptSetup } = this.descriptor;
    const translate = scriptSetup?.content ?? "";
    s.replace(translate, "\n" + importCode.toString() + translate);
    return s.toString();
  }
};

// src/parser/declaration.ts
import { promises, readdirSync } from "fs";
import MagicString2 from "magic-string";
import { normalizePath } from "vite";
var Declaration = class {
  constructor(dir) {
    this.dir = dir;
  }
  path;
  files;
  comps;
  create() {
    this.path = normalizePath(process.cwd()) + this.dir;
    this.files = readdirSync(this.path);
  }
  component(files) {
    this.comps = files.filter((f) => f.endsWith(".vue") && !f.startsWith("index")).map((s) => new MagicString2(s).replaceAll(".vue", "").toString().toLowerCase());
  }
  transform(comps) {
    const code = comps.map((v) => `function ${v}(fn):[{value:boolean} , typeof import('vue')['ref']] ;`);
    const s = new MagicString2(code.join("\n"));
    s.prepend("type fn = (params?:any)=> void \ndeclare namespace $dialog { \n").append("\n}");
    return s.toString();
  }
  visable(path) {
    if (!path.endsWith(".vue"))
      return false;
    const files = readdirSync(this.path);
    if (files.length === this.files.length)
      return false;
    this.files = files;
    return true;
  }
  updatedts() {
    this.component(this.files);
    const s = this.transform(this.comps);
    this.wirtedts(s);
  }
  wirtedts(s) {
    promises.writeFile(this.path + "/com.d.ts", s, "utf-8");
  }
};

// src/index.ts
var VitePluginVueDialog = (options = { dirs: "src/components" }) => {
  const opt = options ?? {};
  let parser;
  let declaration;
  declaration = new Declaration("/" + opt.dirs);
  return {
    name: "vite-pligin-vue-dialog",
    enforce: "pre",
    async configResolved(_conifg) {
      declaration.create();
      declaration.updatedts();
    },
    handleHotUpdate(ctx) {
      const visable = declaration.visable(ctx.file);
      if (visable)
        declaration.updatedts();
    },
    async transform(code, id) {
      if (/\.vue$/.test(id) || /\.vue\?.*type=script.*/.test(id)) {
        parser = new Parser(code);
        if (!parser.unimport)
          await parser.createUnImport(declaration.path);
        await parser.isUnImport();
        if (!parser.isImport) {
          return null;
        }
        parser.parseCode(code);
        const importCode = parser.importMoundle(parser.autoAddImport);
        const s = parser.transformer(code, importCode);
        return s;
      }
    }
  };
};
var src_default = VitePluginVueDialog;
export {
  VitePluginVueDialog,
  src_default as default
};
